[gnome-shell] notificationDaemon: only ignore 'chat' and 'presence' notifications from Empathy (#645932)



commit 9396d736f29acb066e2cc54b2bc098aead196c6f
Author: Guillaume Desmottes <guillaume desmottes collabora co uk>
Date:   Tue Mar 29 10:04:47 2011 +0200

    notificationDaemon: only ignore 'chat' and 'presence' notifications from Empathy (#645932)

 js/ui/notificationDaemon.js |    6 ++++--
 1 files changed, 4 insertions(+), 2 deletions(-)
---
diff --git a/js/ui/notificationDaemon.js b/js/ui/notificationDaemon.js
index d2a50d0..d82dd35 100644
--- a/js/ui/notificationDaemon.js
+++ b/js/ui/notificationDaemon.js
@@ -189,9 +189,11 @@ NotificationDaemon.prototype = {
                      actions, hints, timeout) {
         let id;
 
         // Filter out notifications from Empathy, since we
         // handle that information from telepathyClient.js
-        if (appName == 'Empathy') {
+        if (appName == 'Empathy' && (hints['category'] == 'im.received' ||
+              hints['category'] == 'presence.online' ||
+              hints['category'] == 'presence.offline')) {
             // Ignore replacesId since we already sent back a
             // NotificationClosed for that id.
             id = nextNotificationId++;
@@ -189,9 +189,11 @@ NotificationDaemon.prototype = {
         let id;
 
-        // Filter out notifications from Empathy, since we
+        // Filter out chat and presence notifications from Empathy, since we
         // handle that information from telepathyClient.js



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]